==> nextcloud-30.0.12.tar.bz2: nextcloud/apps/oauth2/l10n/es.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Tu cliente no está autorizado a conectarse. Por favor, informa de tu cliente al administrador.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Tu URL de redirección debe ser una URL completa, por ejemplo: https://tudominio.com/ruta",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Permite autenticación con OAuth2 desde otras aplicaciones web.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "La app OAuth2 permite a los administradores configurar el flujo de trabajo de autenticación incorporado para permitir también autenticación compatible con OAuth2 desde otras aplicaciones web.",
    "OAuth 2.0 clients" : "Clientes OAuth 2.0",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 permite a servicios externos solicitar acceso a {instanceName}",
    "Name" : "Nombre",
    "Redirection URI" : "URI de redirección",
    "Client Identifier" : "Identificador de cliente",
    "Secret key" : "Llave secreta",
    "Delete client" : "Eliminar cliente",
    "Make sure you store the secret key, it cannot be recovered." : "Guarda la clave secreta, porque no se podrá ver más tarde.",
    "Add client" : "Añadir cliente",
    "Add" : "Añadir",
    "Show client secret" : "Mostrar secreto del cliente",
    "Hide client secret" : "Ocultar secreto del cliente",
    "Delete" : "Eliminar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-30.0.15.tar.bz2: nextcloud/apps/oauth2/l10n/es.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Tu cliente no está autorizado a conectarse. Por favor, informa de tu cliente al administrador.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Tu URL de redirección debe ser una URL completa, por ejemplo: https://tudominio.com/ruta",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Permite autenticación con OAuth2 desde otras aplicaciones web.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "La app OAuth2 permite a los administradores configurar el flujo de trabajo de autenticación incorporado para permitir también autenticación compatible con OAuth2 desde otras aplicaciones web.",
    "OAuth 2.0 clients" : "Clientes OAuth 2.0",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 permite a servicios externos solicitar acceso a {instanceName}",
    "Name" : "Nombre",
    "Redirection URI" : "URI de redirección",
    "Client Identifier" : "Identificador de cliente",
    "Secret key" : "Clave secreta",
    "Delete client" : "Eliminar cliente",
    "Make sure you store the secret key, it cannot be recovered." : "Asegúrese de guardar la clave secreta, ya que no podrá ser recuperada.",
    "Add client" : "Añadir cliente",
    "Add" : "Añadir",
    "Show client secret" : "Mostrar secreto del cliente",
    "Hide client secret" : "Ocultar secreto del cliente",
    "Delete" : "Eliminar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
